@@ -8,9 +8,9 @@ from PySide2.QtWidgets import *
 from PIL import Image, ImageFont
 from handright import Template, handwrite
 
-from moduels.GenerateImagesThread import GenerateImagesThread
-from moduels.ConsoleWindow import ConsoleWindow
-from moduels.ColorLabel import ColorLabel
+from QuickHand.moduels.GenerateImagesThread import GenerateImagesThread
+from QuickHand.moduels.ConsoleWindow import ConsoleWindow
+from QuickHand.moduels.ColorLabel import ColorLabel
 # 参考 https://github.com/Gsllchb/Handright/blob/master/docs/tutorial.md
 
 class HandRightTab(QWidget):
